@@ -50,7 +50,10 @@ function destroyLivesIndication() {
 }
 
 function shipHit() {
-    destroyShipSound.play();
+    if (Settings.SFX == "TRUE"){
+        destroyShipSound.play();
+    }
+
     if (lives > 1) {
         lives--;
         if (livesindication[lives - 1]) {
@@ -89,9 +92,10 @@ function createBullet() {
         if (Settings.FlashOnFire == "TRUE") {
             flashanim.start();
         }
-        console.log(shootSound.status);
 
-        shootSound.play();
+        if (Settings.SFX == "TRUE"){
+            shootSound.play();
+        }
         bullet.x = ship.x + ship.width/2 - bullet.width/2;
         bullet.y = ship.y
     }
@@ -344,7 +348,10 @@ function checkBulletAlienCollision() {
         if (bullet && aliens[i]) { //Check if objects exist first
             if (bullet.x > aliens[i].x && bullet.x < aliens[i].x + aliens[i].width) {
                 if (bullet.y > aliens[i].y && bullet.y < aliens[i].y + aliens[i].height) {
-                    destroyAlienSound.play();
+                    if (Settings.SFX == "TRUE"){
+                        destroyAlienSound.play();
+                    }
+
                     aliens[i].destroy();
                     aliens[i] = null;
                     score += 100;
